# Quotee

Small App To get **Quotes** depend on *Zenquotes Api*

## Quotee Usage

```py
from quotee.random import Quotee

example = Quotee()
quote = example.quote
author = example.author

print(quote)
print(author)
```
